Coverage for dateutil\tz\__init__.py: 0%

# Coverage for dateutil\tz\__init__.py : 0%

## 5 statements 0 run 5 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 | # -*- coding: utf-8 -*- from .tz import * from .tz import __doc__ #: Convenience constant providing a :class:`tzutc()` instance #: #: .. versionadded:: 2.7.0 UTC = tzutc() __all__ = ["tzutc", "tzoffset", "tzlocal", "tzfile", "tzrange", "tzstr", "tzical", "tzwin", "tzwinlocal", "gettz", "enfold", "datetime_ambiguous", "datetime_exists", "resolve_imaginary", "UTC", "DeprecatedTzFormatWarning"] class DeprecatedTzFormatWarning(Warning): """Warning raised when time zones are parsed from deprecated formats."""